@@ -2,7 +2,7 @@
 from gemd.entity.valid_list import ValidList
 
 
-def validate_list(obj, typ, trigger=None):
+def validate_list(obj, typ, *, trigger=None):
     """
     Attempts to return obj as a list, each element of which has type typ.
 
@@ -24,7 +24,7 @@ def validate_list(obj, typ, trigger=None):
     """
     if obj is None:
         return ValidList([], typ, trigger)
-    elif isinstance(obj, list):
+    elif isinstance(obj, (list, tuple)):
         return ValidList(obj, typ, trigger)
     else:
         return ValidList([obj], typ, trigger)
